# scikit-learn Branding

This section contains scikit-learn's branding standards.
File types:
- `PNG` is a higher-quality compression format; size of file is generally larger
- `ICO` file format refers to an image file format that contains small size computer icon images
- `SVG` Scalable Vector Graphics (SVG) are an XML-based markup language for describing two-dimensional based vector graphics. They can be created and edited with any text editor or with drawing software.

---

# scikit-learn: Font, Colors & Logos

## scikit-learn Font
- "scikit": Helvetica Neue
- "learn": Script MT

## scikit-learn Color Palette
![#29ABE2 Cyan](brand_colors/colorswatch_29ABE2_cyan.png) `RGB 41/171/226 | HEX #29ABE2 | scikit-learn Cyan` | More info: [#29ABE2](https://www.color-hex.com/color/29abe2)

![#F7931E Orange](brand_colors/colorswatch_F7931E_orange.png)  `RGB 247/147/30 | HEX #F7931E | scikit-learn Orange` | More info: [#F7931E](https://www.color-hex.com/color/f7931e)

![#9B4600 Brown](brand_colors/colorswatch_9B4600_brown.png) `RGB 155/70/0| HEX #9B4600 | scikit-learn Brown` | More info: [#9B4600](https://www.color-hex.com/color/9b4600)

## scikit-learn Logos

### Logo 1
- File type: PNG
- File size: 49 KB (1280 x 689 px)
- File name: [1280px-scikit-learn-logo.png](https://github.com/scikit-learn/scikit-learn/blob/main/doc/logos/1280px-scikit-learn-logo.png)

<img src="1280px-scikit-learn-logo.png" width="250px">

<br>

### Logo 2
- File type: ICO
- File size: 2 KB (32 x 32 px)
- File name: [favicon.ico](https://github.com/scikit-learn/scikit-learn/blob/main/doc/logos/favicon.ico)

<img src="favicon.ico" width="100px">

<br>

### Logo 3
- File type: SVG
- File size: 5 KB
- File name: [scikit-learn-logo-without-subtitle.svg](https://github.com/scikit-learn/scikit-learn/blob/main/doc/logos/scikit-learn-logo-without-subtitle.svg)

<img src="scikit-learn-logo-without-subtitle.svg" width="250px">

---

## Reference
- [color-hex](https://www.color-hex.com): Glossary of Color Palettes

## Other
You can find more variations of the logos here:  https://github.com/scikit-learn/blog/tree/main/assets/images
